## Description
<!-- Provide a brief description of the changes in this PR -->

## Type of Change
<!-- Mark the relevant option with an 'x' -->
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Code quality improvement

## Checklist
<!-- Mark completed items with an 'x' -->
- [ ] My code follows the code style of this project (ruff check passes)
- [ ] My code is properly formatted (ruff format passes)
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] I have updated the documentation accordingly
- [ ] My changes generate no new warnings

## Testing
<!-- Describe the tests you ran to verify your changes -->

## Additional Notes
<!-- Any additional information that reviewers should know -->
